//
//  DataManager.h
//  LocationApp_Sample
//
//  Copyright (c) 2015 ZENRIN DataCom CO., LTD. All Rights Reserved.
//

#import <Foundation/Foundation.h>

/* int型の空の値 */
extern int const IntEmptyValue;
/* float型の空の値 */
extern float const FloatEmptyValue;
/* double型の空の値 */
extern double const DoubleEmptyValue;

@interface DataManager : NSObject

/* LocationManagerLibraryパラメータ */
@property (assign, nonatomic) BOOL permission;
@property (assign, nonatomic) int logUploadCount;
@property (assign, nonatomic) BOOL debugMode;

@property (copy, nonatomic) NSString *appTokenClientID;
@property (copy, nonatomic) NSString *appTokenSecret;
@property (copy, nonatomic) NSString *tokenUrl;

@property (copy, nonatomic) NSString *appApiKey;
@property (copy, nonatomic) NSString *locationUrl;
@property (copy, nonatomic) NSString *deviceID;
@property (copy, nonatomic) NSString *extra;
@property (copy, nonatomic) NSString *unsearchableExtra;
@property (assign, nonatomic) BOOL isSearch;

@property (copy, nonatomic) NSString *libApiKey;
@property (copy, nonatomic) NSString *libTokenClientID;
@property (copy, nonatomic) NSString *libTokenSecret;
@property (assign, nonatomic) int libAuthEnv;

@property (assign, nonatomic) float accuracy;
@property (assign, nonatomic) float distance;
@property (assign, nonatomic) float batteryLevInterval;
@property (assign, nonatomic) float significantChangeAccuracy;
@property (assign, nonatomic) BOOL lowEnergyMode;
@property (assign, nonatomic) double monitoringAreaSmallRadius;
@property (assign, nonatomic) double monitoringAreaMiddleRadius;
@property (assign, nonatomic) double monitoringAreaLargeRadius;
@property (assign, nonatomic) double monitoringAreaOversizeRadius;
@property (assign, nonatomic) double monitoringSlowSpeed;
@property (assign, nonatomic) double monitoringMiddleSpeed;
@property (assign, nonatomic) double monitoringHighSpeed;

/* ライブラリ設定値を指定して初期化する */
- (instancetype)initWithLibSettings:(NSDictionary *)settings;

/* アプリ設定値を返す */
- (NSDictionary *)appSettings;
/* ライブラリ設定値を返す */
- (NSDictionary *)libSettings;

/* アプリ設定値の保存 */
- (void)saveAppSettings;
/* ライブあり設定値の保存 */
- (void)saveLibSettings;
/* アプリ及びライブラリ設定値の復元 */
- (void)restoreSettings;
/* アプリ設定値のリセット */
- (void)resetAppSettings;
/* ライブラリ設定値のリセット */
- (void)resetLibSettings;
/* アプリ設定の送信パラメータ必須判定 */
- (BOOL)isRequiredAppSendingParameters;

@end
