//
//  SettingViewController.m
//  LocationApp_Sample
//
//  Copyright (c) 2012 ZENRIN DataCom CO., LTD. All Rights Reserved.
//

#import "SettingViewController.h"

#import "SettingCell.h"
#import "Storyboard.h"

@interface SettingViewController ()
{
    /* 編集対象のTextField */
    __strong UITextField *_targetTextField;
}

@end


@implementation SettingViewController

- (instancetype)initWithCoder:(NSCoder *)aDecoder
{
    self = [super initWithCoder:aDecoder];
    if (self != nil)
    {
        _targetTextField = nil;
    }
    return self;
}

#pragma mark UITableViewDataSource

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 0;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return 0;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return nil;
}

#pragma mark UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return 44.0f;
}

#pragma mark Public

/* スイッチセルを返す */
- (UITableViewCell *)switchCell:(NSString *)title isOn:(BOOL)isOn
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kSwitchCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    UISwitch *cellSwitch = [cell switchInCell];
    cellSwitch.on = isOn;
    
    return cell;
}

/* ボタンセルを返す */
- (UITableViewCell *)buttonCell:(NSString *)title
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kButtonCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    return cell;
}

/* プルダウンセルを返す */
- (UITableViewCell *)pullDownCell:(NSString *)title menu:(UIMenu *)menu selectedMenu:(NSString *)selectedMenu
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kPullDownCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;

    UIButton *pullDown = [cell pullDownCell];
    pullDown.menu = menu;

    [pullDown setTitle:selectedMenu forState:UIControlStateNormal];
    return cell;
}

/* 短いタイトルセル(編集可)を返す */
- (UITableViewCell *)shortTitleTextFieldCell:(NSString *)title text:(NSString *)text keyboardType:(UIKeyboardType)keyboardType
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kShortTitleTextFieldCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    UITextField *textField = [cell textFieldInCell];
    textField.text = text;
    textField.keyboardType = keyboardType;

    return cell;
}

/* 長いタイトルセル(編集不可)を返す */
- (UITableViewCell *)shortTitleFixedTextFieldCell:(NSString *)title text:(NSString *)text
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kShortTitleFixedTextFieldCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    UITextField *textField = [cell textFieldInCell];
    textField.text = text;
    
    return cell;
}

/* 短いタイトルセル(編集可)を返す */
- (UITableViewCell *)longTitleTextFieldCell:(NSString *)title text:(NSString *)text keyboardType:(UIKeyboardType)keyboardType
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kLongTitleTextFieldCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    UITextField *textField = [cell textFieldInCell];
    textField.text = text;
    textField.keyboardType = keyboardType;
    
    return cell;
}

/* 短いタイトルセル(編集不可)を返す */
- (UITableViewCell *)longTitleFixedTextFieldCell:(NSString *)title text:(NSString *)text
{
    SettingCell *cell = [self.tableView dequeueReusableCellWithIdentifier:kLongTitleFixedTextFieldCellIdentifier];
    
    UILabel *titleLabel = [cell titleLabelInCell];
    titleLabel.text =title;
    
    UITextField *textField = [cell textFieldInCell];
    textField.text = text;
    
    return cell;
}

/* セルのAccessoryViewに対するIndexPathを返す */
- (NSIndexPath *)indexPathForAccessoryView:(UIView *)accessoryView
{
    NSIndexPath *indexPath = nil;
    
    for (SettingCell *visibleCell in self.tableView.visibleCells)
    {
        if ([visibleCell hasAccessoryView:accessoryView])
        {
            indexPath = [self.tableView indexPathForCell:visibleCell];
            break;
        }
    }
    return indexPath;
}

/* int型の値に対するテキストを返す */
- (NSString *)textFromInt:(int)value
{
    if (value == IntEmptyValue)
    {
        return nil;
    }
    return [@(value) stringValue];
}

/* float型の値に対するテキストを返す */
- (NSString *)textFromFloat:(float)value
{
    if (value == FloatEmptyValue)
    {
        return nil;
    }
    return [@(value) stringValue];
}

/* double型の値に対するテキストを返す */
- (NSString *)textFromDouble:(double)value
{
    if (value == DoubleEmptyValue)
    {
        return nil;
    }
    return [@(value) stringValue];
}

/* 文字列アラート表示 */
- (void)showTextAlert:(NSString *)title message:(NSString *)message
{
    NSString *okButtonTitle = @"OK";
    
    if (NSClassFromString(@"UIAlertController") != nil)
    {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:title
                                                                                 message:message
                                                                          preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:okButtonTitle
                                                            style:UIAlertActionStyleDefault
                                                          handler:nil]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

/* 初期化アラート表示 */
- (void)showResetAlert:(OkBlock)block
{
    NSString *title = @"初期化";
    NSString *message = @"設定値を初期化します";
    NSString *cancelButtonTitle = @"Cancel";
    NSString *okButtonTitle = @"OK";
    
    if (NSClassFromString(@"UIAlertController") != nil)
    {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:title
                                                                                 message:message
                                                                          preferredStyle:UIAlertControllerStyleAlert];
        
        void (^handler)(UIAlertAction *action) = ^(UIAlertAction *action){
            if ([action.title isEqualToString:okButtonTitle])
            {
                block();
            }
        };

        [alertController addAction:[UIAlertAction actionWithTitle:cancelButtonTitle
                                                            style:UIAlertActionStyleCancel
                                                          handler:handler]];
        [alertController addAction:[UIAlertAction actionWithTitle:okButtonTitle
                                                            style:UIAlertActionStyleDefault
                                                          handler:handler]];
        
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

/* アラート表示 */
- (void)showInputAlert:(NSString *)title cell:(SettingCell *)cell ok:(OkReturnValueBlock)block
{
    NSString *message = [cell titleLabelInCell].text;
    NSString *cancelButtonTitle = @"Cancel";
    NSString *okButtonTitle = @"OK";
    void (^configurationHandler)(UITextField *textField) = ^(UITextField *textField){
        textField.text = self->_targetTextField.text;
        textField.keyboardType = self->_targetTextField.keyboardType;
        [textField becomeFirstResponder];
    };
    
    _targetTextField = [cell textFieldInCell];
    
    if (NSClassFromString(@"UIAlertController") != nil)
    {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:title
                                                                                 message:message
                                                                          preferredStyle:UIAlertControllerStyleAlert];
        void (^handler)(UIAlertAction *action) = ^(UIAlertAction *action){
            UITextField *alertTextField = alertController.textFields[0];
            [alertTextField resignFirstResponder];
            
            if ([action.title isEqualToString:okButtonTitle])
            {
                block(alertTextField.text);
            }
            self->_targetTextField = nil;
        };
        [alertController addAction:[UIAlertAction actionWithTitle:cancelButtonTitle
                                                            style:UIAlertActionStyleCancel
                                                          handler:handler]];
        [alertController addAction:[UIAlertAction actionWithTitle:okButtonTitle
                                                            style:UIAlertActionStyleDefault
                                                          handler:handler]];
        [alertController addTextFieldWithConfigurationHandler:configurationHandler];
        
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

@end
